{% extends "base.html" %}
{% block main_content %}
<div class="col-12 col-md-8">
  <p class="text-center display-3 text-primary"><i class="bi bi-cloud-sleet"></i></p>
  <p class="text-center display-4">404 Not Found</p>
  <p>お探しのページは見つかりませんでした。次のいずれかが原因の可能性があります。</p>
  <ul>
    <li>サイトは一時的にメンテナンス中である</li>
    <li>この記事は移動もしくは削除された</li>
  </ul>
  <p class="d-md-flex d-none">画面左側の記事一覧および右上の検索ボックスより、記事をお探しいただけます。</p>
  <p class="d-md-none">画面上部の「<i class="bi bi-book"></i>」アイコンをクリックすることで、記事をお探しいただけます。</p>
</div> 
{% endblock %}